searchNodes=[{"doc":"Pundit provides a set of helpers which guide you in leveraging regular Elixir methods to build a simple authorization system. This library is based heavily on Jonas Nicklas' Ruby project of the same name . Simple Elixir functions are defined for a given struct and allow you to encapsulate authentication logic. You can use this code within a module that is an Ecto.Schema , but that's not necessary. The action names are taken from the list of actions defined by Phoenix controllers . Examples Here's a basic example, starting with a simple struct for a Post . A module named Post.Policy should be created to encapsulate all of the access methods ( Pundit will automatically look for the &lt;struct module&gt;.Policy module to determine the module name to look at for access methods). To declare an initial set of access functions ( show? , edit? , delete? , etc) which all return false (default safe!), just use Pundit.DefaultPolicy . You can then override the functions as needed with the logic necessary to determine whether a user should be able to perform the given action. In this example, we only determine whether a user can edit? a post, leaving all other functions (like delete? ) to return the default of false . defmodule Post do defstruct [ :author , :title , :body , :comments ] defmodule Policy do # This will initialize all the functions listed below, that all return false # by default. Override them individually to return true when they should. use Pundit.DefaultPolicy def edit? ( post , user ) do user . name == post . author end end end post = % Post { author : &quot;Snake Plissken&quot; } author = %{ name : &quot;Snake Plissken&quot; } # next line is same as Pundit.can?(post, author, :edit?) if Pundit . edit? ( post , author ) do IO . puts ( &quot;Can edit!&quot; ) end if Pundit . delete? ( post , author ) do IO . puts ( &quot;This line should never be called&quot; ) end # raise exception if user should be able to do a thing Pundit . authorize! ( post , author , :edit? ) Scope You can also provide query scope for a struct (say, if you're using Ecto.Schema ) for a given user. For instance, say our Post was an Ecto schema. Our function for scoping all Post s to a specific User could be to find all Post s that were authored by a user. For instance: defmodule Post do use Ecto.Schema import Ecto.Query , only : [ from : 2 ] defmodule Policy do use Pundit.DefaultPolicy def scope ( query , user ) do from post in query , where : post . author_id == ^ user . id end end end user = MyApp.Repo . get ( User , 1 ) posts = Pundit . scope ( Post , user ) |&gt; Repo . all ( ) query = from p in Post , where : p . comment_count &gt; 10 popular_posts = Pundit . scope ( query , user ) |&gt; Repo . all ( )","ref":"Pundit.html","title":"Pundit","type":"module"},{"doc":"Return a tuple based on whether a user can perform the action on the thing. Returns {:ok} if a user can perform the action, or {:error, message} if not.","ref":"Pundit.html#authorize/3","title":"Pundit.authorize/3","type":"function"},{"doc":"Raise a Pundit.NotAuthorizedError exception unless the user can perform the action on the thing.","ref":"Pundit.html#authorize!/3","title":"Pundit.authorize!/3","type":"function"},{"doc":"Determine if a use can perform an action on a given thing. This will attempt to call a function with the same name as the action on the policy module of the given thing. For instance: Pundit . can? ( post , user , :edit? ) is the same as: Post.Policy . edit? ( post , user )","ref":"Pundit.html#can?/3","title":"Pundit.can?/3","type":"function"},{"doc":"Returns true only if the user should be allowed to create a new kind of thing.","ref":"Pundit.html#create?/2","title":"Pundit.create?/2","type":"function"},{"doc":"Returns true only if the user should be allowed to delete a thing.","ref":"Pundit.html#delete?/2","title":"Pundit.delete?/2","type":"function"},{"doc":"Returns true only if the user should be allowed to see a form for updating the thing. See the page on Phoenix controllers for more details on the purpose of this action.","ref":"Pundit.html#edit?/2","title":"Pundit.edit?/2","type":"function"},{"doc":"Returns true only if the user should be allowed to see an index (list) of the given things.","ref":"Pundit.html#index?/2","title":"Pundit.index?/2","type":"function"},{"doc":"Returns true only if the user should be allowed to see a form to create a new thing. See the page on Phoenix controllers for more details on the purpose of this action.","ref":"Pundit.html#new?/2","title":"Pundit.new?/2","type":"function"},{"doc":"Scope a Ecto.Query or Ecto.Schema to a given user. This will call the function scope on the policy module of the given thing. For instance: Pundit . scope ( Post , user ) is the same as: Post.Policy . scope ( Post , user ) Here's an example with a Ecto.Query : query = from post in Post , where : post . comments &gt; 10 # This call... Pundit . scope ( query , user ) # Is the same as... Post.Policy . scope ( query , user ) This is just helpful shorthand.","ref":"Pundit.html#scope/2","title":"Pundit.scope/2","type":"function"},{"doc":"Returns true only if the user should be allowed to see the given thing.","ref":"Pundit.html#show?/2","title":"Pundit.show?/2","type":"function"},{"doc":"Returns true only if the user should be allowed to update the attributes of a thing.","ref":"Pundit.html#update?/2","title":"Pundit.update?/2","type":"function"},{"doc":"Default access policies for a given type. All of the functions here are named for actions in a Phoenix controller . If you use this module, then default implementations will be added in your module that all return false by default (default safe, nothing is permitted). All are overrideable.","ref":"Pundit.DefaultPolicy.html","title":"Pundit.DefaultPolicy","type":"behaviour"},{"doc":"Returns true only if the user should be allowed to create a new kind of thing.","ref":"Pundit.DefaultPolicy.html#c:create?/2","title":"Pundit.DefaultPolicy.create?/2","type":"callback"},{"doc":"Returns true only if the user should be allowed to delete a thing.","ref":"Pundit.DefaultPolicy.html#c:delete?/2","title":"Pundit.DefaultPolicy.delete?/2","type":"callback"},{"doc":"Returns true only if the user should be allowed to see a form for updating the thing. See the page on Phoenix controllers for more details on the purpose of this action.","ref":"Pundit.DefaultPolicy.html#c:edit?/2","title":"Pundit.DefaultPolicy.edit?/2","type":"callback"},{"doc":"Returns true only if the user should be allowed to see an index (list) of the given things.","ref":"Pundit.DefaultPolicy.html#c:index?/2","title":"Pundit.DefaultPolicy.index?/2","type":"callback"},{"doc":"Returns true only if the user should be allowed to see a form to create a new thing. See the page on Phoenix controllers for more details on the purpose of this action.","ref":"Pundit.DefaultPolicy.html#c:new?/2","title":"Pundit.DefaultPolicy.new?/2","type":"callback"},{"doc":"Returns true only if the user should be allowed to see the given thing.","ref":"Pundit.DefaultPolicy.html#c:show?/2","title":"Pundit.DefaultPolicy.show?/2","type":"callback"},{"doc":"Returns true only if the user should be allowed to update the attributes of a thing.","ref":"Pundit.DefaultPolicy.html#c:update?/2","title":"Pundit.DefaultPolicy.update?/2","type":"callback"},{"doc":"Exception raised when a user attempts to perform an action they're not authorized to perform.","ref":"Pundit.NotAuthorizedError.html","title":"Pundit.NotAuthorizedError","type":"exception"},{"doc":"Exception raised when a module doesn't implement a necessary access function.","ref":"Pundit.NotDefinedError.html","title":"Pundit.NotDefinedError","type":"exception"},{"doc":"Pundit provides a set of helpers which guide you in leveraging regular Elixir methods to build a simple authorization system. This library is based heavily on Jonas Nicklas' Ruby project of the same name . Simple Elixir functions are defined for a given struct and allow you to encapsulate authentication logic. You can use this code within a module that is an Ecto.Schema, but that's not necessary (Ecto isn't required). The action names are taken from the list of actions defined by Phoenix controllers .","ref":"readme.html","title":"Pundit","type":"extras"},{"doc":"To install Pundit, just add an entry to your mix.exs : def deps do [ # ... { :pundit , &quot;~&gt; 1.0&quot; } ] end (Check Hex to make sure you're using an up-to-date version number.)","ref":"readme.html#installation","title":"Pundit - Installation","type":"extras"},{"doc":"Here's a basic example, starting with a simple struct for a Post . A module named Post.Policy should be created to encapsulate all of the access methods ( Pundit will automatically look for the &lt;struct module&gt;.Policy module to determine the module name to look at for access methods). To declare an initial set of access functions ( show? , edit? , delete? , etc) which all return false (default safe!), just use Pundit.DefaultPolicy . You can then override the functions as needed with the logic necessary to determine whether a user should be able to perform the given action. In this example, we only determine whether a user can edit? a post, leaving all other functions (like delete? ) to return the default of false . defmodule Post do defstruct [ :author , :title , :body , :comments ] defmodule Policy do # This will initialize all the action functions, all of which return false # by default. Override them individually to return true when they should, # like edit? is overriden below. use Pundit.DefaultPolicy def edit? ( post , user ) do user . name == post . author end end end post = % Post { author : &quot;Snake Plissken&quot; } author = %{ name : &quot;Snake Plissken&quot; } # next line is same as Pundit.can?(post, author, :edit?) # Pundit will just delegate to Post.Policy.edit?(post, user) if Pundit . edit? ( post , author ) do IO . puts ( &quot;Can edit!&quot; ) end if Pundit . delete? ( post , author ) do IO . puts ( &quot;This line should never be called&quot; ) end # raise exception if user should be able to do a thing Pundit . authorize! ( post , author , :edit? )","ref":"readme.html#usage","title":"Pundit - Usage","type":"extras"},{"doc":"You can also provide query scope for a struct (say, if you're using Ecto.Schema ) for a given user. For instance, say our Post was an Ecto schema. Our function for scoping all Post s to a specific User could be to find all Post s that were authored by a user. For instance: defmodule Post do use Ecto.Schema import Ecto.Query , only : [ from : 2 ] defmodule Policy do use Pundit.DefaultPolicy def scope ( query , user ) do from post in query , where : post . author_id == ^ user . id end end end user = MyApp.Repo . get ( User , 1 ) posts = Pundit . scope ( Post , user ) |&gt; Repo . all ( ) query = from p in Post , where : p . comment_count &gt; 10 popular_posts = Pundit . scope ( query , user ) |&gt; Repo . all ( ) See the docs for more examples.","ref":"readme.html#scope","title":"Pundit - Scope","type":"extras"},{"doc":"To run tests: $ mix test","ref":"readme.html#running-tests","title":"Pundit - Running Tests","type":"extras"},{"doc":"Please report all issues on github .","ref":"readme.html#reporting-issues","title":"Pundit - Reporting Issues","type":"extras"}]